%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% diffusion_data.m
% Assumes: a) all data are in same folder b) data are aligned and
% anatomical volume is transformed to all spaces (please comment lines out
% if not the case)
%
% Works with BrainVoyager QX 2.2
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

bvqx = actxserver('BrainVoyagerQX.BrainVoyagerQXScriptAccess.1')
bvqx.PrintToLog('Start processing diffusion weighted data...');

% ~~~ this part will require modifications, if used for own purposes ~~~
dmrname = 'C:/Data/bvqxdata/Human31dir/human31dir_from_script.dmr'; % this variable is also used in 2nd part
answer = questdlg('Create diffusion project?', 'Create DMR');
if answer == 'Yes'
    dmr = bvqx.CreateProjectDMR( 'DICOM', 'C:/Data/bvqxdata/Human31dir/pimpul_070907_dti -0007-0001-00001.dcm', ...
    31, 0, true, 75, 'human31dir', false, 128, 128, 2, 'C:/Data/bvqxdata/Human31dir');
    dmr.SaveAs(dmrname);
end

% ~~~ this part does not require modifications, is all user-interface based ~~~
% if alignment files happen to be available, one could as well create
% normalized diffusion weighted data files:
answer = questdlg('Create normalized diffusion data? (requires *.trf files)', 'Create VDW');
if answer == 'Yes'
    [pathstr, name, ext, versn] = fileparts(dmrname)
    [FileName, PathName] = uigetfile('*.vmr','Please select the anatomical file...');
    vmr = bvqx.OpenDocument([PathName FileName]);
    iafilename = dir([PathName '*_IA.trf']) % assumes a single initial alignment file in the directory of the VMR
    fafilename = dir([PathName '*_FA.trf']) % assumes a single fine alignment file in the directory of the VMR
    acpcfilename = dir([PathName '*_ACPC.trf']) % assumes a single AC-PC transformation file in the directory of the VMR
    talfilename = dir([PathName '*.tal']) % assumes a single Talairach landmark file in the directory of the VMR
    answer = questdlg('Would you like a high-precision data format (float)?', 'Datatype');
    if answer == 'Yes'
        datatype = 2;
    else
        datatype = 1;
    end
    resolutionlist = {'1mm^3', '2mm^3', '3mm^3'};
    [resolution, ok] = listdlg('PromptString','Select the target resolution:',...
        'SelectionMode','single',...
        'Name', 'VDW resolution',...
        'ListString', resolutionlist);
    interpolationlist = {'nearest neighbor', 'trilinear', 'sinc'};
    [interpolation, ok] = listdlg('PromptString','Select the interpolation type:',...
        'SelectionMode','single',...
        'Name', 'Interpolation',...
        'ListString', interpolationlist)
    interpolation = interpolation - 1; % 0: nearest neighbour, 1: trilinear interpolation, 2: interpolation.

    prompt = {'Enter intensity threshold:'};%,'Enter colormap name:'};
    dlg_title = 'Intensity threshold';
    num_lines = 1;
    def = {'100'};%,'hsv'};
    threshold = inputdlg(prompt,dlg_title,num_lines,def);
    ia = [PathName iafilename(1).name] % takes first initial alignment file it finds in folder
    fa = [PathName fafilename(1).name] % takes first fine alignment file it finds in folder
    acpc = [PathName acpcfilename(1).name] % takes first AC-PC alignment file it finds in folder
    tal = [PathName talfilename(1).name] % takes first Talairach landmarks file it finds in folder
    thresh =  str2num(threshold{1})
    vmr.ExtendedTALSpaceForVTCCreation = 0; % no extended bounding box for cerebellum
    vdw =  fullfile(pathstr, [name '_native.vdw'])
    success = vmr.CreateVDWInVMRSpace(dmrname,ia,fa,vdw,datatype,resolution, interpolation, thresh);
    vdw =  fullfile(pathstr, [name '_acpc.vdw'])
    success = vmr.CreateVDWInACPCSpace(dmrname,ia,fa,acpc,vdw,datatype,resolution, interpolation, thresh);
    vdw =  fullfile(pathstr, [name '_tal.vdw'])
    success = vmr.CreateVDWInTALSpace(dmrname,ia,fa,acpc,tal,vdw,datatype,resolution, interpolation, thresh);
end
bvqx.PrintToLog('Finished processing diffusion data.');
